# Package for calculating phonon contribution in RIXS

This package aims to create a convenient set of tools for fitting experimental data and obtaining electron-phonon coupling values from phonon contribution in resonant inelastic X-ray scattering cross-section.

It currently includes:
- Model for 1D harmonic oscillator interacting with a single electronic level.
- Model for 2D harmonic oscillator (two modes active).
- Model for 1D harmonic oscillator, distorted and displaced in the excited state (excited-state potential energy surface (PES), differs from the ground state one).

---
### Installation
It is a python based package and to install it you can simply run in terminal:

`$pip install phlab`

Download examples folder from this page and use it as a template for your projects. You may want to use Jupyter Notebooks, which comes with the examples. If you don't have [Jupyter](https://jupyter.org/documentation) install it  via `pip` as well:

`$pip install jupyterlab`
